@@ -45,6 +45,7 @@ class Face(_BaseWithShade):
         * boundary_condition
         * apertures
         * doors
+        * sub_faces
         * indoor_shades
         * outdoor_shades
         * parent
@@ -189,14 +190,19 @@ class Face(_BaseWithShade):
 
     @property
     def apertures(self):
-        """Get a list of apertures in this Face."""
+        """Get a tuple of apertures in this Face."""
         return tuple(self._apertures)
 
     @property
     def doors(self):
-        """Get a list of doors in this Face."""
+        """Get a tuple of doors in this Face."""
         return tuple(self._doors)
 
+    @property
+    def sub_faces(self):
+        """Get a tuple of apertures and doors in this Face."""
+        return tuple(self._apertures + self._doors)
+
     @property
     def parent(self):
         """Get the parent Room if assigned. None if not assigned."""
@@ -993,6 +999,25 @@ class Face(_BaseWithShade):
                 'tolerance.\n{}'.format(self.full_id, e))
         self._punched_geometry = None  # reset so that it can be re-computed
 
+    def remove_degenerate_sub_faces(self, tolerance=0.01):
+        """Remove colinear vertices from sub-faces and eliminate degenerate ones.
+
+        Args:
+            tolerance: The minimum distance between a vertex and the boundary segments
+                at which point the vertex is considered colinear. Default: 0.01,
+                suitable for objects in meters.
+        """
+        for i, ap in enumerate(self._apertures):
+            try:
+                ap.remove_colinear_vertices(tolerance)
+            except ValueError:
+                self._apertures.pop(i)
+        for i, dr in enumerate(self._doors):
+            try:
+                dr.remove_colinear_vertices(tolerance)
+            except ValueError:
+                self._apertures.pop(i)
+
     def check_sub_faces_valid(self, tolerance=0.01, angle_tolerance=1,
                               raise_exception=True):
         """Check that sub-faces are co-planar with this Face within the Face boundary.
@@ -1074,6 +1099,22 @@ class Face(_BaseWithShade):
             raise ValueError(full_msg)
         return full_msg
 
+    def check_sub_faces_overlapping(self, raise_exception=True):
+        """Check that this Face's sub-faces do not overlap with one another.
+
+        Args:
+            raise_exception: Boolean to note whether a ValueError should be raised
+                if a sub-faces overlap with one another.
+        """
+        full_msg = ''
+        sub_f_area = sum(sf.area for sf in self.sub_faces)
+        if sub_f_area > self.area:
+            full_msg = 'Face "{}" contains Apertures and/or ' \
+                'Doors that overlap with each other.'.format(self.full_id)
+            if raise_exception:
+                raise ValueError(full_msg)
+        return full_msg
+
     def check_planar(self, tolerance=0.01, raise_exception=True):
         """Check whether all of the Face's vertices lie within the same plane.
 
