@@ -142,9 +142,13 @@ class Model(_Base):
         assert data['type'] == 'Model', 'Expected Model dictionary. ' \
             'Got {}.'.format(data['type'])
 
-        # import the tolerance values
-        tol = 0 if 'tolerance' not in data else data['tolerance']
-        angle_tol = 0 if 'angle_tolerance' not in data else data['angle_tolerance']
+        # import the units and tolerance values
+        units = 'Meters' if 'units' not in data or data['units'] is None \
+            else data['units']
+        tol = cls.UNITS_TOLERANCES[units] if 'tolerance' not in data or \
+            data['tolerance'] is None else data['tolerance']
+        angle_tol = 1.0 if 'angle_tolerance' not in data or \
+            data['angle_tolerance'] is None else data['angle_tolerance']
 
         # import all of the geometry
         rooms = None  # import rooms
@@ -164,9 +168,6 @@ class Model(_Base):
         if 'orphaned_doors' in data and data['orphaned_doors'] is not None:
             orphaned_doors = [Door.from_dict(d) for d in data['orphaned_doors']]
 
-        # import the units
-        units = 'Meters' if 'units' not in data else data['units']
-
         # build the model object
         model = Model(data['identifier'], rooms, orphaned_faces, orphaned_shades,
                       orphaned_apertures, orphaned_doors, units, tol, angle_tol)
@@ -988,6 +989,7 @@ class Model(_Base):
                 msgs.append(str(e))
         # perform geometry checks related to parent-child relationships
         msgs.append(self.check_sub_faces_valid(tol, ang_tol, False))
+        msgs.append(self.check_sub_faces_overlapping(False))
         msgs.append(self.check_rooms_solid(tol, ang_tol, False))
         # check the extension attributes
         msgs.extend(self._properties._check_extension_attr())
@@ -1151,6 +1153,27 @@ class Model(_Base):
             raise ValueError(full_msg)
         return full_msg
 
+    def check_sub_faces_overlapping(self, raise_exception=True):
+        """Check that model's sub-faces do not overlap with one another.
+
+        Args:
+            raise_exception: Boolean to note whether a ValueError should be raised
+                if a sub-faces overlap with one another.
+        """
+        msgs = []
+        for rm in self._rooms:
+            msg = rm.check_sub_faces_overlapping(False)
+            if msg != '':
+                msgs.append(msg)
+        for f in self._orphaned_faces:
+            msg = f.check_sub_faces_overlapping(False)
+            if msg != '':
+                msgs.append(msg)
+        full_msg = '\n'.join(msgs)
+        if raise_exception and len(msgs) != 0:
+            raise ValueError(full_msg)
+        return full_msg
+
     def check_planar(self, tolerance, raise_exception=True):
         """Check that all of the Model's geometry components are planar.
 
